@@ -1,16 +1,11 @@
-# -*- coding: utf-8 -*-
 """Collection of functions for the manipulation of time series."""
 
-from __future__ import absolute_import, division, print_function
 
 import itertools
-import os
 import warnings
 
-import mando
-import typic
-from mando.rst_text_formatter import RSTHelpFormatter
-from tstoolbox import tsutils
+from pydantic import validate_arguments
+from toolbox_utils import tsutils
 
 warnings.filterwarnings("ignore")
 
@@ -230,7 +225,7 @@ ldocstrings[
         +-------+----------------+
         | d     | thin diamond   |
         +-------+----------------+
-        | _     | hlines_y       |
+        | _     | hline          |
         +-------+----------------+
         | None  | nothing        |
         +-------+----------------+
@@ -630,69 +625,61 @@ def know_your_limits(xylimits, axis="arithmetic"):
         if nlim[0] < 0 or nlim[0] > 1 or nlim[1] < 0 or nlim[1] > 1:
             raise ValueError(
                 tsutils.error_wrapper(
-                    """
+                    f"""
 Both limits must be between 0 and 1 for the 'normal', 'lognormal', or 'weibull'
 axis.
 
-Instead you have {}.
-""".format(
-                        nlim
-                    )
+Instead you have {nlim}.
+"""
                 )
             )
 
     if nlim is None:
         return nlim
 
-    if nlim[0] is not None and nlim[1] is not None:
-        if nlim[0] >= nlim[1]:
-            raise ValueError(
-                tsutils.error_wrapper(
-                    """
+    if nlim[0] is not None and nlim[1] is not None and nlim[0] >= nlim[1]:
+        raise ValueError(
+            tsutils.error_wrapper(
+                f"""
 The second limit must be greater than the first.
 
-You gave {}.
-""".format(
-                        nlim
-                    )
-                )
+You gave {nlim}.
+"""
             )
+        )
 
-    if axis == "log":
-        if (nlim[0] is not None and nlim[0] <= 0) or (
-            nlim[1] is not None and nlim[1] <= 0
-        ):
-            raise ValueError(
-                tsutils.error_wrapper(
-                    """
+    if axis == "log" and (
+        (nlim[0] is not None and nlim[0] <= 0) or (nlim[1] is not None and nlim[1] <= 0)
+    ):
+        raise ValueError(
+            tsutils.error_wrapper(
+                f"""
 If log plot cannot have limits less than or equal to 0.
 
-You have {}.
-""".format(
-                        nlim
-                    )
-                )
+You have {nlim}.
+"""
             )
+        )
 
     return nlim
 
 
-@typic.al
+@validate_arguments
 def check_column_legend(plottype, tsd, legend_names):
     # print("in ck_col_lg :", plottype, type(tsd), len(tsd.columns), type(legend_names), legend_names)
     # Check number of columns.
-    if plottype in ["bootstrap", "heatmap", "autocorrelation", "lag_plot"]:
-        if len(tsd.columns) != 1:
-            raise ValueError(
-                tsutils.error_wrapper(
-                    """
-The '{1}' plot can only work with 1 time-series in the DataFrame.
-The DataFrame that you supplied has {0} time-series.
-""".format(
-                        len(tsd.columns), plottype
-                    )
-                )
+    if (
+        plottype in ["bootstrap", "heatmap", "autocorrelation", "lag_plot"]
+        and len(tsd.columns) != 1
+    ):
+        raise ValueError(
+            tsutils.error_wrapper(
+                f"""
+The '{plottype}' plot can only work with 1 time-series in the DataFrame.
+The DataFrame that you supplied has {len(tsd.columns)} time-series.
+"""
             )
+        )
 
     # Check legend_names.
     if not legend_names:
@@ -717,54 +704,47 @@ Each name in legend_names must be unique.
     else:
         raise ValueError(
             tsutils.error_wrapper(
-                """
+                f"""
 For 'legend_names' and most plot types you must have the same number of comma
-separated names as columns in the input data.  The input data has {} where the
-number of 'legend_names' is {}.
+separated names as columns in the input data.  The input data has {len(tsd.columns)} where the
+number of 'legend_names' is {len(legend_names)}.
 
 If `type` is 'xy' or 'double_mass' you need to have legend names as
 l1,l2,l3,...  where l1 is the legend for x1,y1, l2 is the legend for x2,y2,
 ...etc.
-""".format(
-                    len(tsd.columns), len(legend_names)
-                )
+"""
             )
         )
-        tsd.rename(columns=renamedict, inplace=True)
+
+    tsd = tsd.rename(columns=renamedict)
     legend_names = tsd.columns
 
     return tsd, legend_names
 
 
 def prepare_styles(ntrace, style, colors, linestyles, markerstyles):
-    if colors == "auto":
-        colors = None
-    else:
-        colors = tsutils.make_list(colors)
-
-    if linestyles == "auto":
+    colors = None if colors == "auto" else tsutils.make_list(colors)
+    if "auto" in linestyles:
         linestyles = LINE_LIST
     else:
         linestyles = tsutils.make_list(linestyles)
 
-    if markerstyles == "auto":
+    if "auto" in markerstyles:
         markerstyles = MARKER_LIST
     else:
         markerstyles = tsutils.make_list(markerstyles)
         if markerstyles is None:
             markerstyles = " "
-    if style != "auto":
+    if "auto" not in style:
         nstyle = tsutils.make_list(style)
         if len(nstyle) != ntrace:
             raise ValueError(
                 tsutils.error_wrapper(
-                    """
+                    f"""
 You have to have the same number of style strings as traces to plot.
-You supplied '{}' for style which has {} style strings,
-but you have {} traces.
-""".format(
-                        style, len(nstyle), ntrace
-                    )
+You supplied '{style}' for style which has {len(nstyle)} style strings,
+but you have {ntrace} traces.
+"""
                 )
             )
         colors = []
@@ -791,11 +771,62 @@ but you have {} traces.
         linestyles = [" " if i in ["  ", None] else i for i in linestyles]
     markerstyles = [" " if i is None else i for i in markerstyles]
 
-    if colors is not None:
-        icolors = itertools.cycle(colors)
-    else:
-        icolors = None
+    icolors = itertools.cycle(colors) if colors is not None else None
     imarkerstyles = itertools.cycle(markerstyles)
     ilinestyles = itertools.cycle(linestyles)
 
     return style, colors, linestyles, markerstyles, icolors, ilinestyles, imarkerstyles
+
+
+def hv_lines(
+    plt,
+    hlines_y=None,
+    hlines_xmin=None,
+    hlines_xmax=None,
+    hlines_colors=None,
+    hlines_linestyles=None,
+    vlines_x=None,
+    vlines_ymin=None,
+    vlines_ymax=None,
+    vlines_colors=None,
+    vlines_linestyles=None,
+):
+    if hlines_y is not None:
+        hlines_y = tsutils.make_list(hlines_y)
+        hlines_xmin = tsutils.make_list(hlines_xmin)
+        hlines_xmax = tsutils.make_list(hlines_xmax)
+        hlines_colors = tsutils.make_list(hlines_colors)
+        hlines_linestyles = tsutils.make_list(hlines_linestyles)
+        nxlim = plt.get_xlim()
+        if hlines_xmin is None:
+            hlines_xmin = nxlim[0]
+        if hlines_xmax is None:
+            hlines_xmax = nxlim[1]
+    if vlines_x is not None:
+        vlines_x = tsutils.make_list(vlines_x)
+        vlines_ymin = tsutils.make_list(vlines_ymin)
+        vlines_ymax = tsutils.make_list(vlines_ymax)
+        vlines_colors = tsutils.make_list(vlines_colors)
+        vlines_linestyles = tsutils.make_list(vlines_linestyles)
+        nylim = plt.get_ylim()
+        if vlines_ymin is None:
+            vlines_ymin = nylim[0]
+        if vlines_ymax is None:
+            vlines_ymax = nylim[1]
+    if hlines_y is not None:
+        plt.hlines(
+            hlines_y,
+            hlines_xmin,
+            hlines_xmax,
+            colors=hlines_colors,
+            linestyles=hlines_linestyles,
+        )
+    if vlines_x is not None:
+        plt.vlines(
+            vlines_x,
+            vlines_ymin,
+            vlines_ymax,
+            colors=vlines_colors,
+            linestyles=vlines_linestyles,
+        )
+    return plt
